MethodChannelAdiscopeFlutterPlugin class

An implementation of AdiscopeFlutterPluginPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getNetworkVersions() → Future<String?>
override
getSDKVersion() → Future<String?>
override
getUnitStatus(String unitId) → Future<Map?>
override
getUnitStatusRewardedInterstitial(String unitId) → Future<Map?>
override
initialize([String mediaId = "", String mediaSecret = "", String callbackTag = "", String childYN = ""]) → Future<bool?>
override
interstitialIsLoad(String unitId) → Future<bool?>
override
interstitialLoad(String unitId) → Future<bool?>
override
interstitialShow() → Future<bool?>
override
interstitialShowWithLoad(String unitId) → Future<bool?>
override
isInitialized() → Future<bool?>
override
loadRewardedInterstitial(String unitId) → Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preLoadAllRewardedInterstitial() → Future<bool?>
override
preLoadRewardedInterstitial(List<String>? unitIds) → Future<bool?>
override
rewardedInterstitialIsLoad(String unitId) → Future<bool?>
override
rewardedVideoIsLoad(String unitId) → Future<bool?>
override
rewardedVideoLoad(String unitId) → Future<bool?>
override
rewardedVideoShow() → Future<bool?>
override
rewardedVideoShowWithLoad(String unitId) → Future<bool?>
override
setLuckyEventAppId(String eventId, String pid) → Future<bool?>
override
setLuckyEventBaseUrl(String baseUrl) → Future<bool?>
override
setLuckyEventExtraParam(String key, String value) → Future<bool?>
override
setLuckyEventHashMark(String hashMark) → Future<bool?>
override
setLuckyEventUseSafeAreaWebView(bool useSafeArea) → Future<bool?>
override
setRewardedCheckParam(String param) → Future<bool?>
override
setShowWithLoad2BackgroundColor(String red, String green, String blue, String alpha) → Future<bool?>
override
setShowWithLoad2ErrorAlert(String msg, bool isHidden) → Future<bool?>
override
setShowWithLoad2IndicatorStyle(bool isMedium, bool isHidden) → Future<bool?>
override
setUserId(String userId) → Future<bool?>
override
setUserIdChild(String userId, int child) → Future<bool?>
override
setVolumeOff(bool isOn) → Future<bool?>
override
showAdmobMediationDebugger() → Future<bool?>
override
showLuckyEvent() → Future<bool?>
override
showMaxMediationDebugger() → Future<bool?>
override
showOfferwall(String unitId, [List<String>? offerwallFilterTabs]) → Future<bool?>
override
showOfferwallDetail(String unitId, String itemId, [List<String>? offerwallFilterTabs]) → Future<bool?>
override
showOfferwallDetailFromUrl(String url) → Future<bool?>
override
showRewardedInterstitial(String unitId) → Future<bool?>
override
showWithPopupRewardedInterstitial(String unitId) → Future<bool?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited