AdiscopeFlutterPlugin class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getNetworkVersions()
→ Future<String?>
-
Check the versions of third-party networks
-
getSDKVersion()
→ Future<String?>
-
Check adiscope sdk version
-
getUnitStatus(String unitId)
→ Future<Map?>
-
Check unit status of offerwall or rewardedvideo with
unitId
-
getUnitStatusRewardedInterstitial(String unitId)
→ Future<Map?>
-
Check unit status of offerwall or RewardedInterstitial with
unitId
-
initialize([String mediaId = "", String mediaSecret = "", String callbackTag = "", String childYN = ""])
→ Future<bool?>
-
Initialize adisocpe with
mediaid, mediasecret, callbackTag, childYN.
-
interstitialIsLoad(String unitId)
→ Future<bool?>
-
Check the Load status of the interstitial of the
unitId value.
-
interstitialLoad(String unitId)
→ Future<bool?>
-
Load interstitial of
unitId value.
-
interstitialShow()
→ Future<bool?>
-
Show interstitial.
-
interstitialShowWithLoad(String unitId)
→ Future<bool?>
-
Show With Load interstitial of
unitId value.
-
isInitialized()
→ Future<bool?>
-
Check initialize
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
preLoadAllRewardedInterstitial()
→ Future<bool?>
-
Loads all units of RewardedInterstitial.
-
preLoadRewardedInterstitial(List<String>? unitIds)
→ Future<bool?>
-
Loads the
unitIds values of RewardedInterstitial.
-
rewardedVideoIsLoad(String unitId)
→ Future<bool?>
-
Check the Load status of the rewardedVideo of the
unitId value.
-
rewardedVideoLoad(String unitId)
→ Future<bool?>
-
Load rewardedVideo of
unitId value.
-
rewardedVideoShow()
→ Future<bool?>
-
Show rewardedVideo.
-
rewardedVideoShowWithLoad(String unitId)
→ Future<bool?>
-
Show With Load rewardedVideo of
unitId value.
-
setLuckyEventAppId(String eventId, String pid)
→ Future<bool?>
-
Set Lucky Event of Event AppId & PubId.
-
setLuckyEventBaseUrl(String baseUrl)
→ Future<bool?>
-
Set Lucky Event of BaseUrl.
-
Set Lucky Event of ExtraParam.
-
setLuckyEventHashMark(String hashMark)
→ Future<bool?>
-
Set Lucky Event of HashMark.
-
setLuckyEventUseSafeAreaWebView(bool useSafeArea)
→ Future<bool?>
-
Set Lucky Event of SafeArea.
-
setRewardedCheckParam(String param)
→ Future<bool?>
-
Add Rewarded Callback
-
setShowWithLoad2BackgroundColor(String red, String green, String blue, String alpha)
→ Future<bool?>
-
Adjust advertising sound with
isOn
-
setShowWithLoad2ErrorAlert(String msg, bool isHidden)
→ Future<bool?>
-
Adjust advertising sound with
isOn
-
setShowWithLoad2IndicatorStyle(bool isMedium, bool isHidden)
→ Future<bool?>
-
Adjust advertising sound with
isOn
-
setUserId(String userId)
→ Future<bool?>
-
User information settings
-
setVolumeOff(bool isOn)
→ Future<bool?>
-
Adjust advertising sound with
isOn
-
showAdmobMediationDebugger()
→ Future<bool?>
-
Admob Mediation Debugger
-
showLuckyEvent()
→ Future<bool?>
-
Show Lucky Event.
-
showMaxMediationDebugger()
→ Future<bool?>
-
Max Mediation Debugger
-
showOfferwall(String unitId, [List<String>? offerwallFilterTabs])
→ Future<bool?>
-
The offer wall of
unitId is exposed, and the filter value is set to offerwallFilterTabs.
-
showOfferwallDetail(String unitId, String itemId, [List<String>? offerwallFilterTabs])
→ Future<bool?>
-
The offer wall detail page of
unitId, itemId is exposed, and the filter value is set to offerwallFilterTabs.
-
showOfferwallDetailFromUrl(String url)
→ Future<bool?>
-
Exposes the offer wall detail page of
unitId, itemId.
-
showRewardedInterstitial(String unitId)
→ Future<bool?>
-
Show interstitial of
unitId value.
-
toString()
→ String
-
A string representation of this object.
inherited